Ammo class

Constructors

Ammo({required DragModel dm, Velocity? mv, Temperature? powderTemp, double tempModifier = 0.0, bool usePowderSensitivity = false})

Properties

dm DragModel
final
hashCode int
The hash code for this object.
no setterinherited
mv Velocity
final
powderTemp Temperature
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tempModifier double
getter/setter pair
usePowderSensitivity bool
getter/setter pair

Methods

calcPowderSens(Velocity otherVelocity, Temperature otherTemperature) double
getVelocityForTemp(Temperature currentTemp) Velocity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited