AsyncCalculator class

Constructors

AsyncCalculator({BcIntegrationMethod method = BcIntegrationMethod.rk4, BcConfig? config})

Properties

config → BcConfig
final
hashCode → int
The hash code for this object.
no setterinherited
method → BcIntegrationMethod
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

aimingSolutionForTarget(Shot shot, Distance targetDistance) → Future<(Angular, Angular, TrajectoryData)>
Async counterpart to Calculator.aimingSolutionForTarget.
barrelElevationForTarget(Shot shot, Distance targetDistance) → Future<Angular>
Async counterpart to Calculator.barrelElevationForTarget.
fire({required Shot shot, required Distance trajectoryRange, Distance? trajectoryStep, double timeStep = 0.0, int filterFlags = 8, bool raiseRangeError = true}) → Future<HitResult>
Async counterpart to Calculator.fire.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setWeaponZero(Shot shot, Distance zeroDistance) → Future<Angular>
Async counterpart to Calculator.setWeaponZero.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited