winds property
Wind list – pointer must remain valid for the duration of the call.
Implementation
external ffi.Pointer<BCLIBCFFI_Wind> winds;
Wind list – pointer must remain valid for the duration of the call.
external ffi.Pointer<BCLIBCFFI_Wind> winds;