BCLIBCFFI_Wind class final

Inheritance
Implemented types
Available extensions

Constructors

BCLIBCFFI_Wind()

Properties

address Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
direction_from_rad double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
max_distance_ft double
< Sentinel for last segment (use BCLIBC_cMaxWindDistanceFeet)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
until_distance_ft double
getter/setter pair
velocity_fps double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited