DragModel class

Constructors

DragModel({required double bc, required List dragTable, Weight? weight, Distance? diameter, Distance? length})

Properties

bc → double
final
diameter → Distance
final
dragTable → List<DragDataPoint>
final
formFactor ↔ double
latefinal
hashCode → int
The hash code for this object.
no setterinherited
length → Distance
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionalDensity ↔ double
latefinal
weight → Weight
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited