HitResult class

Inheritance

Constructors

HitResult(Shot shot, List<TrajectoryData> records, {int filterFlags = 0, Exception? error})

Properties

error → Exception?
final
events → List<TrajectoryData>
Exact physical event roots (ZERO, MACH, APEX, and MRT).
latefinal
filterFlags → int
final
first → TrajectoryData
The first element.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<TrajectoryData>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last → TrajectoryData
The last element.
no setterinherited
length → int
The number of elements in this Iterable.
no setteroverride
records → List<TrajectoryData>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samples → List<TrajectoryData>
Scheduled samples, with an event flag attached only at the same instant.
latefinal
shot → Shot
final
single → TrajectoryData
Checks that this iterable has only one element, and returns that element.
no setterinherited
trajectory → List<TrajectoryData>
no setter
zeros → List<TrajectoryData>
no setter

Methods

any(bool test(TrajectoryData element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
cast<R>() → Iterable<R>
A view of this iterable as an iterable of R instances.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
elementAt(int index) → TrajectoryData
Returns the indexth element.
inherited
every(bool test(TrajectoryData element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(TrajectoryData element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(TrajectoryData element), {TrajectoryData orElse()?}) → TrajectoryData
The first element that satisfies the given predicate test.
inherited
flag(TrajFlag requested) → TrajectoryData?
Returns the first exact row matching requested, or null when absent.
fold<T>(T initialValue, T combine(T previousValue, TrajectoryData element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<TrajectoryData> other) → Iterable<TrajectoryData>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(TrajectoryData element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
getAtDistance(Distance d) → TrajectoryData
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(TrajectoryData element), {TrajectoryData orElse()?}) → TrajectoryData
The last element that satisfies the given predicate test.
inherited
map<T>(T toElement(TrajectoryData e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(TrajectoryData combine(TrajectoryData value, TrajectoryData element)) → TrajectoryData
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
singleWhere(bool test(TrajectoryData element), {TrajectoryData orElse()?}) → TrajectoryData
The single element that satisfies test.
inherited
skip(int count) → Iterable<TrajectoryData>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(TrajectoryData element)) → Iterable<TrajectoryData>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<TrajectoryData>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(TrajectoryData element)) → Iterable<TrajectoryData>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<TrajectoryData>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<TrajectoryData>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
where(bool test(TrajectoryData element)) → Iterable<TrajectoryData>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<R>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → TrajectoryData