Pressure class

Inheritance

Constructors

Pressure(double value, Unit unit)
Pressure.atm(double value)
factory
Pressure.bar(double value)
factory
Pressure.hPa(double value)
factory
Pressure.inHg(double value)
factory
Pressure.mmHg(double value)
factory
Pressure.psi(double value)
factory

Properties

conversionFactors → Map<Unit, double>
no setteroverride
debugDetails → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setterinherited
raw → double
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
units → Unit
no setterinherited
value → double
no setterinherited

Methods

in_(Unit unit) → double
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
to(Unit unit) → Pressure
inherited
toDouble() → double
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

accepts(Unit u) → bool

Constants

rawUnit → const Unit