Temperature class

Inheritance

Constructors

Temperature(double value, Unit unit)
Temperature.celsius(double value)
factory
Temperature.fahrenheit(double value)
factory
Temperature.kelvin(double value)
factory
Temperature.rankin(double value)
factory

Properties

conversionFactors → Map<Unit, double>
no setteroverride
debugDetails → String
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setterinherited
raw → double
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
units → Unit
no setterinherited
value → double
no setterinherited

Methods

in_(Unit unit) → double
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
to(Unit unit) → Temperature
inherited
toDouble() → double
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

accepts(Unit u) → bool

Constants

rawUnit → const Unit