BCLIBCFFI_IntegrationMethod enum
Values
- BCLIBCFFI_INTEGRATION_RK4 → const BCLIBCFFI_IntegrationMethod
-
const BCLIBCFFI_IntegrationMethod(0) - BCLIBCFFI_INTEGRATION_EULER → const BCLIBCFFI_IntegrationMethod
-
const BCLIBCFFI_IntegrationMethod(1) - BCLIBCFFI_INTEGRATION_VELOCITY_VERLET → const BCLIBCFFI_IntegrationMethod
-
const BCLIBCFFI_IntegrationMethod(2) - BCLIBCFFI_INTEGRATION_CASH_KARP → const BCLIBCFFI_IntegrationMethod
-
EXPERIMENTAL -- see bclibc/cash_karp.hpp's doc comment before relying on this for anything accuracy-sensitive: known event- interpolation regressions under this method's sparse/irregular step spacing (see project issue tracker).
const BCLIBCFFI_IntegrationMethod(3) - BCLIBCFFI_INTEGRATION_DORMAND_PRINCE → const BCLIBCFFI_IntegrationMethod
-
const BCLIBCFFI_IntegrationMethod(4) - BCLIBCFFI_INTEGRATION_TSITOURAS → const BCLIBCFFI_IntegrationMethod
-
Adaptive Tsitouras 5(4) ("Tsit5") -- same FSAL shape and step-size controller as BCLIBCFFI_INTEGRATION_DORMAND_PRINCE, see bclibc/tsitouras.hpp's doc comment.
const BCLIBCFFI_IntegrationMethod(5)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → BCLIBCFFI_IntegrationMethod
Constants
-
values
→ const List<
BCLIBCFFI_IntegrationMethod> - A constant List of the values in this enum, in order of their declaration.