BCLIBCFFI_ShotProps class final
Flat shot properties passed to every engine function.
- Inheritance
- Implemented types
- Available extensions
Constructors
Properties
-
address
→ Pointer<
T> -
Available on T, provided by the StructAddress extension
The memory address of the underlying data.no setter - alt0_ft ↔ double
-
getter/setter pair
- atmo ↔ BCLIBCFFI_Atmosphere
-
getter/setter pair
- barrel_azimuth_rad ↔ double
-
getter/setter pair
- barrel_elevation_rad ↔ double
-
getter/setter pair
- bc ↔ double
-
getter/setter pair
- cant_angle_rad ↔ double
-
getter/setter pair
- config ↔ BCLIBCFFI_Config
-
getter/setter pair
- coriolis ↔ BCLIBCFFI_Coriolis
-
getter/setter pair
- diameter_inch ↔ double
-
getter/setter pair
-
drag_table
↔ Pointer<
BCLIBCFFI_DragPoint> -
Drag table – pointer must remain valid for the duration of the call.
getter/setter pair
- drag_table_count ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- length_inch ↔ double
-
getter/setter pair
- look_angle_rad ↔ double
-
getter/setter pair
- method → BCLIBCFFI_IntegrationMethod
-
no setter
- methodAsInt ↔ int
-
getter/setter pair
- muzzle_velocity_fps ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sight_height_ft ↔ double
-
getter/setter pair
- twist_inch ↔ double
-
getter/setter pair
- weight_grain ↔ double
-
getter/setter pair
- wind_count ↔ int
-
getter/setter pair
-
winds
↔ Pointer<
BCLIBCFFI_Wind> -
Wind list – pointer must remain valid for the duration of the call.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited