Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
calculateEnergy(double bulletWeightGrain, double velocityFps)
→ double
-
-
calculateOgw(double bulletWeightGrain, double velocityFps)
→ double
-
-
findApexShot(BcShot shot)
→ BcTrajectoryData
-
-
findMaxRangeShot(BcShot shot, {double lowAngleDeg, double highAngleDeg})
→ BcMaxRangeResult
-
-
findZeroAngleShot(BcShot shot, double distanceFt)
→ double
-
-
findZeroPointShot(BcShot shot, double distanceFt)
→ BcZeroPointResult
-
-
getCorrection(double distanceFt, double offsetFt)
→ double
-
-
integrateAtShot(BcShot shot, BcBaseTrajInterpKey key, double targetValue)
→ BcInterception
-
-
integrateShot(BcShot shot, BcTrajectoryRequest request)
→ BcHitResult
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited