aimingSolutionForTarget method
Returns the vertical hold, windage, and target-range trajectory point.
The point is retained by the native zero solver, avoiding a separate trajectory integration after the zero angle has been found.
Implementation
(Angular, Angular, TrajectoryData) aimingSolutionForTarget(
Shot shot,
Distance targetDistance,
) => calcAimingSolutionForTarget(
_engine,
method,
config,
shot,
targetDistance,
);