Shot class
Constructors
Properties
- ammo → Ammo
-
final
- atmo → Atmo
-
final
- azimuthDeg ↔ double?
-
getter/setter pair
- barrelAzimuth → Angular
-
no setter
- barrelElevation ↔ Angular
-
getter/setter pair
- cantAngle → Angular
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitudeDeg ↔ double?
-
getter/setter pair
- lookAngle → Angular
-
final
- relativeAngle ↔ Angular
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slantAngle → Angular
-
no setter
- weapon → Weapon
-
final
-
winds
↔ List<
Wind> -
getter/setter pair
Methods
-
calculateStabilityCoefficient(
) → double - Calculate the Miller stability coefficient.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited